ParserTokenFlags

Struct ParserTokenFlags 

pub struct ParserTokenFlags(/* private fields */);
Parser-inferred semantic usage for an individual token occurrence.

This complements lexical token kind and helps distinguish ambiguous tokens (for example keyword text used as an identifier).

Implementations

Source

impl ParserTokenFlags

pub fn bits(self) -> u8

Returns the underlying flag bits.

pub fn used_as_identifier(self) -> bool

True if the token was used as an identifier (SYNQ_TOKEN_FLAG_AS_ID).

pub fn used_as_function(self) -> bool

True if the token was used as a function name (SYNQ_TOKEN_FLAG_AS_FUNCTION).

pub fn used_as_type(self) -> bool

True if the token was used as a type name (SYNQ_TOKEN_FLAG_AS_TYPE).