pub struct ParserTokenFlags(/* private fields */);Expand description
Parser-inferred semantic usage for an individual token occurrence.
This complements lexical token kind and helps distinguish ambiguous tokens (for example keyword text used as an identifier).
Implementations
Sourceimpl ParserTokenFlags
impl ParserTokenFlags
Sourcepub fn used_as_identifier(self) -> bool
pub fn used_as_identifier(self) -> bool
True if the token was used as an identifier (SYNQ_TOKEN_FLAG_AS_ID).
Sourcepub fn used_as_function(self) -> bool
pub fn used_as_function(self) -> bool
True if the token was used as a function name (SYNQ_TOKEN_FLAG_AS_FUNCTION).
Sourcepub fn used_as_type(self) -> bool
pub fn used_as_type(self) -> bool
True if the token was used as a type name (SYNQ_TOKEN_FLAG_AS_TYPE).